createApiKeysApiKeysRevoke method
Future<CreateApiKeys200Response?>
createApiKeysApiKeysRevoke(
- String companyId,
- String apiKeyId,
- ApiKeysInput apiKeysInput
Explicitly revoke an API key with reason tracking. This is different from delete as it includes revocation metadata.
Parameters:
-
String companyId (required): Unique identifier for the Company
-
String apiKeyId (required): Unique identifier for the Api Key
-
ApiKeysInput apiKeysInput (required):
Implementation
Future<CreateApiKeys200Response?> createApiKeysApiKeysRevoke(String companyId, String apiKeyId, ApiKeysInput apiKeysInput,) async {
final response = await createApiKeysApiKeysRevokeWithHttpInfo(companyId, apiKeyId, apiKeysInput,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'CreateApiKeys200Response',) as CreateApiKeys200Response;
}
return null;
}