updateApiKeys method

Future<UpdateApiKeys200Response?> updateApiKeys(
  1. String companyId,
  2. String apiKeyId,
  3. ApiKeysUpdate apiKeysUpdate
)

Update an existing API key by ID. Can update metadata like name, expiration, rate limits, etc. Cannot update the actual key value (for security).

Parameters:

  • String companyId (required): Unique identifier for the Company

  • String apiKeyId (required): Unique identifier for the Api Key

  • ApiKeysUpdate apiKeysUpdate (required):

Implementation

Future<UpdateApiKeys200Response?> updateApiKeys(String companyId, String apiKeyId, ApiKeysUpdate apiKeysUpdate,) async {
  final response = await updateApiKeysWithHttpInfo(companyId, apiKeyId, apiKeysUpdate,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'UpdateApiKeys200Response',) as UpdateApiKeys200Response;

  }
  return null;
}