Alerts class

Constructors

Alerts({DateTime? dateCreated, DateTime? lastUpdated, int? alertId, required String assetId, String? userId, required String companyId, required bool isActive})
Returns a new Alerts instance.

Properties

alertId int?
Auto-generated unique identifier.
getter/setter pair
assetId String
References assets.asset_id — A published analytics asset — a calculation or visualization built on a data connection. See GET /assets for valid values. Required.
getter/setter pair
companyId String
References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.
getter/setter pair
dateCreated DateTime?
Optional.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
isActive bool
Whether this alert is currently active
getter/setter pair
lastUpdated DateTime?
Optional.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
References users.user_id — An individual user account within a company. See GET /users for valid values. Optional.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Alerts?
Returns a new Alerts instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Alerts>
mapFromJson(dynamic json) Map<String, Alerts>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Alerts>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.