AlertsApi class

Constructors

AlertsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAlerts(String companyId, String userId, AlertsInput alertsInput) Future<CreateAlerts200Response?>
POST /companies/{company_id}/users/{user_id}/alerts
createAlertsWithHttpInfo(String companyId, String userId, AlertsInput alertsInput) Future<Response>
POST /companies/{company_id}/users/{user_id}/alerts
deleteAlerts(String companyId, String userId, String alertId) Future<DeleteAlerts200Response?>
Delete single alert by ID
deleteAlertsWithHttpInfo(String companyId, String userId, String alertId) Future<Response>
Delete single alert by ID
getAlertsById(String companyId, String userId) Future<GetAlertsById200Response?>
Get a list of all alerts for a specific user
getAlertsByIdAssetAll(String companyId, String userId, String assetId) Future<GetAlertsById200Response?>
Get all alerts for a specific asset
getAlertsByIdAssetAllWithHttpInfo(String companyId, String userId, String assetId) Future<Response>
Get all alerts for a specific asset
getAlertsByIdUsers(String companyId, String userId, String alertId) Future<GetAlertsById200Response?>
Get single alert by ID
getAlertsByIdUsersAsset(String companyId, String userId, String assetId) Future<GetAlertsById200Response?>
Get all alerts for a specific asset (by user)
getAlertsByIdUsersAssetWithHttpInfo(String companyId, String userId, String assetId) Future<Response>
Get all alerts for a specific asset (by user)
getAlertsByIdUsersWithHttpInfo(String companyId, String userId, String alertId) Future<Response>
Get single alert by ID
getAlertsByIdWithHttpInfo(String companyId, String userId) Future<Response>
Get a list of all alerts for a specific user
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateAlerts(String companyId, String userId, String alertId, AlertsUpdate alertsUpdate) Future<UpdateAlerts200Response?>
Update an existing alert by ID
updateAlertsWithHttpInfo(String companyId, String userId, String alertId, AlertsUpdate alertsUpdate) Future<Response>
Update an existing alert by ID

Operators

operator ==(Object other) bool
The equality operator.
inherited