AlertsInput class
Constructors
- AlertsInput({required String assetId, String? userId, required String companyId, bool? isActive})
- Returns a new AlertsInput instance.
Properties
- assetId ↔ String
-
References assets.asset_id — A published analytics asset — a calculation or visualization built on a data connection. See GET /assets for valid values. Required.
getter/setter pair
- companyId ↔ String
-
References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- isActive ↔ bool?
-
Whether this alert is currently active
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId ↔ String?
-
References users.user_id — An individual user account within a company. See GET /users for valid values. Optional.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AlertsInput? -
Returns a new AlertsInput instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AlertsInput> -
mapFromJson(
dynamic json) → Map< String, AlertsInput> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AlertsInput> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.