ApiKeys class

Constructors

ApiKeys({DateTime? dateCreated, DateTime? lastUpdated, required int apiKeyId, String? userId, required String companyId, required int roleId, required String keyType, required bool isSystemGenerated, String? mcpDeploymentId, String? endpointId, String? name, DateTime? expirationDateUtc})
Returns a new ApiKeys instance.

Properties

apiKeyId int
Unique identifier.
getter/setter pair
companyId String
Company this API key belongs to
getter/setter pair
dateCreated DateTime?
Optional.
getter/setter pair
endpointId String?
Endpoint this key is tied to (NULL for analytics/mcp keys)
getter/setter pair
expirationDateUtc DateTime?
When this API key expires (NULL = never expires)
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
isSystemGenerated bool
True if key was auto-generated for MCP deployment
getter/setter pair
keyType String
Type of API key (analytics, mcp, or endpoint)
getter/setter pair
lastUpdated DateTime?
Optional.
getter/setter pair
mcpDeploymentId String?
MCP deployment this key is tied to (NULL for analytics/endpoint keys)
getter/setter pair
name String?
Human-readable name for this API key
getter/setter pair
roleId int
Role/permission level for this API key
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
User who owns this API key
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ApiKeys?
Returns a new ApiKeys instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ApiKeys>
mapFromJson(dynamic json) Map<String, ApiKeys>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ApiKeys>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.