AssetUsecasesApi class

Constructors

AssetUsecasesApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAssetUsecasesById(String aucId) Future<GetAssetUsecasesById200Response?>
Get single asset use case by ID
getAssetUsecasesByIdWithHttpInfo(String aucId) Future<Response>
Get single asset use case by ID
listAssetUsecases({int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<ListAssetUsecases200Response?>
Get a list of all asset use cases
listAssetUsecasesWithHttpInfo({int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<Response>
Get a list of all asset use cases
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited