getAssetsByIdStatistics method

Future<GetAssetsByIdAnalyze200Response?> getAssetsByIdStatistics(
  1. String companyId
)

Get statistics for all assets the user has access to

Parameters:

  • String companyId (required): Unique identifier for the Company

Implementation

Future<GetAssetsByIdAnalyze200Response?> getAssetsByIdStatistics(String companyId,) async {
  final response = await getAssetsByIdStatisticsWithHttpInfo(companyId,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'GetAssetsByIdAnalyze200Response',) as GetAssetsByIdAnalyze200Response;

  }
  return null;
}