CloudProvidersApi class

Constructors

CloudProvidersApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCloudProvidersById(String providerId) Future<GetCloudProvidersById200Response?>
Get single cloud provider by ID
getCloudProvidersByIdWithHttpInfo(String providerId) Future<Response>
Get single cloud provider by ID
listCloudProviders({int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<ListCloudProviders200Response?>
Get a list of all cloud providers
listCloudProvidersWithHttpInfo({int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<Response>
Get a list of all cloud providers
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited