CloudProvidersUpdate class
Constructors
- CloudProvidersUpdate({String? name, String? parentCompany, String? marketingHomepageUrl})
- Returns a new CloudProvidersUpdate instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- marketingHomepageUrl ↔ String?
-
Optional.
getter/setter pair
- name ↔ String?
-
Required.
getter/setter pair
- parentCompany ↔ String?
-
Optional.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → CloudProvidersUpdate? -
Returns a new CloudProvidersUpdate instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< CloudProvidersUpdate> -
mapFromJson(
dynamic json) → Map< String, CloudProvidersUpdate> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< CloudProvidersUpdate> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.