Companies class

Constructors

Companies({DateTime? dateCreated, DateTime? lastUpdated, String? companyId, int? industryId, int? countryId, String? companyName, String? companyDescription, required String companyHandle, required String companyDomain, required int creditsBalance, bool? acceptedEula, String? stripeAccountId, String? stripeAccountStatus, double? vendorSharePercent, CompaniesPartnershipTypeEnum? partnershipType})
Returns a new Companies instance.

Properties

acceptedEula bool?
Optional.
getter/setter pair
companyDescription String?
Optional.
getter/setter pair
companyDomain String
Required. Must be unique.
getter/setter pair
companyHandle String
Required. Must be unique.
getter/setter pair
companyId String?
Unique identifier.
getter/setter pair
companyName String?
Optional.
getter/setter pair
countryId int?
References countries.country_id — List of countries of the world. See GET /countries for valid values. Optional.
getter/setter pair
creditsBalance int
Current balance of credits for this company (buyer)
getter/setter pair
dateCreated DateTime?
Optional.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
industryId int?
References industries.industry_id — Available industry categories for asset classification. Based on US NAISC codes.. See GET /industries for valid values. Optional.
getter/setter pair
lastUpdated DateTime?
Optional.
getter/setter pair
partnershipType CompaniesPartnershipTypeEnum?
Partnership type: SELF_MANAGED, CUSTODIAN, or null
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripeAccountId String?
Stripe Connect account ID for marketplace sellers
getter/setter pair
stripeAccountStatus String?
Status of the Stripe account (verified, pending, etc.)
getter/setter pair
vendorSharePercent double?
Negotiated vendor revenue share (e.g. 0.85 = 85%). NULL = system default 80%.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Companies?
Returns a new Companies instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Companies>
mapFromJson(dynamic json) Map<String, Companies>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Companies>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.