listCompanies method
Get the total number of requests allocated in the company's current subscription plan.
Parameters:
Implementation
Future<ListCompaniesAnalyticsAssets200Response?> listCompanies(String companyId, { int? page, int? limit, String? sortBy, String? sortOrder, String? search, }) async {
final response = await listCompaniesWithHttpInfo(companyId, page: page, limit: limit, sortBy: sortBy, sortOrder: sortOrder, search: search, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'ListCompaniesAnalyticsAssets200Response',) as ListCompaniesAnalyticsAssets200Response;
}
return null;
}