CompaniesCompanyIdApiKeysGet200Response class
Constructors
-
CompaniesCompanyIdApiKeysGet200Response({required String message, List<
ApiKeys> data = const []}) - Returns a new CompaniesCompanyIdApiKeysGet200Response instance.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → CompaniesCompanyIdApiKeysGet200Response? -
Returns a new CompaniesCompanyIdApiKeysGet200Response instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< CompaniesCompanyIdApiKeysGet200Response> -
mapFromJson(
dynamic json) → Map< String, CompaniesCompanyIdApiKeysGet200Response> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< CompaniesCompanyIdApiKeysGet200Response> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.