vendorSharePercent property

double? vendorSharePercent
getter/setter pair

Negotiated vendor revenue share (e.g. 0.85 = 85%). NULL = system default 80%.

Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.

Implementation

double? vendorSharePercent;