CreateAlerts200ResponseData class

Constructors

CreateAlerts200ResponseData({required String alertId})
Returns a new CreateAlerts200ResponseData instance.

Properties

alertId String
ID of the created alerts
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CreateAlerts200ResponseData?
Returns a new CreateAlerts200ResponseData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CreateAlerts200ResponseData>
mapFromJson(dynamic json) Map<String, CreateAlerts200ResponseData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CreateAlerts200ResponseData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.