accessWhitelist property
List of allowed IPs, emails, or domains based on access_method. Format: {type: 'ip'|'email'|'domain', values: '192.168.1.1', ...}
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
Implementation
Object? accessWhitelist;