sampleResponse property

Object? sampleResponse
getter/setter pair

Last successful {spartera, request, response} envelope. Saved on each successful marketplace run. Displayed as preview on product page load.

Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.

Implementation

Object? sampleResponse;