endpointSchema property

Object? endpointSchema
getter/setter pair

Column configurations including aggregations, filters, and visibility. Format: {columns: {name, type, aggregation, filter, is_hidden, alias, ...}}. This is the source of truth — SQL is generated at runtime from this configuration.

Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.

Implementation

Object? endpointSchema;