GetAlertsById200Response class

Constructors

GetAlertsById200Response({required String message, required Alerts data})
Returns a new GetAlertsById200Response instance.

Properties

data Alerts
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
message String
Response status message
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GetAlertsById200Response?
Returns a new GetAlertsById200Response instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GetAlertsById200Response>
mapFromJson(dynamic json) Map<String, GetAlertsById200Response>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GetAlertsById200Response>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.