Industries class

Constructors

Industries({DateTime? dateCreated, DateTime? lastUpdated, int? industryId, required String industryName, required String shortName, String? slug, int? naiscCode, String? description})
Returns a new Industries instance.

Properties

dateCreated DateTime?
Optional.
getter/setter pair
description String?
Optional.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
industryId int?
Auto-generated unique identifier.
getter/setter pair
industryName String
Required. Must be unique.
getter/setter pair
lastUpdated DateTime?
Optional.
getter/setter pair
naiscCode int?
Optional.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortName String
Required.
getter/setter pair
slug String?
Optional.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Industries?
Returns a new Industries instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Industries>
mapFromJson(dynamic json) Map<String, Industries>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Industries>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.