IndustriesApi class

Constructors

IndustriesApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getIndustriesById(String industryId) Future<GetIndustriesById200Response?>
Get single industry by ID
getIndustriesByIdWithHttpInfo(String industryId) Future<Response>
Get single industry by ID
listIndustries({int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<ListIndustries200Response?>
Get a list of all industries
listIndustriesActive({int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<ListIndustries200Response?>
Get a list of industries that have active marketplace products
listIndustriesActiveWithHttpInfo({int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<Response>
Get a list of industries that have active marketplace products
listIndustriesWithHttpInfo({int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<Response>
Get a list of all industries
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited