JobFunctionsApi class

Constructors

JobFunctionsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getJobFunctionsById(String functionId) Future<GetJobFunctionsById200Response?>
Get single job function by ID
getJobFunctionsByIdWithHttpInfo(String functionId) Future<Response>
Get single job function by ID
listJobFunctions({int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<ListJobFunctions200Response?>
Get a list of all job functions
listJobFunctionsWithHttpInfo({int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<Response>
Get a list of all job functions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited