PostPublicationsUpdate class
Constructors
Properties
- companyId ↔ String?
-
Company this publication belongs to
getter/setter pair
- errorMessage ↔ String?
-
Error message if publication failed
getter/setter pair
- externalPostId ↔ String?
-
ID of the post on the external platform
getter/setter pair
- externalPostUrl ↔ String?
-
URL to view the post on the external platform
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- integrationId ↔ String?
-
Integration used for publishing
getter/setter pair
- platform ↔ String?
-
Platform identifier (beehiiv, wordpress, etc)
getter/setter pair
- postId ↔ String?
-
Post that was published
getter/setter pair
- publishedAt ↔ DateTime?
-
When the post was published to this platform
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
Status: published, failed, deleted
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → PostPublicationsUpdate? -
Returns a new PostPublicationsUpdate instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< PostPublicationsUpdate> -
mapFromJson(
dynamic json) → Map< String, PostPublicationsUpdate> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< PostPublicationsUpdate> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.