PostgenIntegrationsInput class

Constructors

PostgenIntegrationsInput({required String companyId, required String userId, required String platform, required String platformName, required String credentialsSecretName, bool? isActive, DateTime? lastUsedAt})
Returns a new PostgenIntegrationsInput instance.

Properties

companyId String
Company this integration belongs to
getter/setter pair
credentialsSecretName String
GCP Secret Manager secret name containing encrypted credentials
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
isActive bool?
Whether this integration is currently active
getter/setter pair
lastUsedAt DateTime?
Last time this integration was used for publishing
getter/setter pair
platform String
Platform identifier (beehiiv, wordpress, medium, etc)
getter/setter pair
platformName String
Display name of the platform
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
User who created this integration
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) PostgenIntegrationsInput?
Returns a new PostgenIntegrationsInput instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<PostgenIntegrationsInput>
mapFromJson(dynamic json) Map<String, PostgenIntegrationsInput>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<PostgenIntegrationsInput>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.