Posts class

Constructors

Posts({DateTime? dateCreated, DateTime? lastUpdated, String? postId, required String userId, required String companyId, required String title, String? category, String? teaser, required String contentHtml, Object? insightsUsed, int? generationCreativity, int? generationTargetWordCount, String? generationTone, bool? generationIncludeCitations, int? generationSubheadingCount, double? generationTemperature, required int dataCostCredits, required int serviceCostCredits, required int totalCostCredits, required int successfulInsightsCount, required int failedInsightsCount, int? generationTimeMs, required bool isPublished, DateTime? publishedAt, required int viewCount, DateTime? lastEditedAt})
Returns a new Posts instance.

Properties

category String?
Article category (e.g., 'Sports', 'Business')
getter/setter pair
companyId String
Company this post belongs to
getter/setter pair
contentHtml String
Generated article HTML content
getter/setter pair
dataCostCredits int
Cost in credits for data insights
getter/setter pair
dateCreated DateTime?
Optional.
getter/setter pair
failedInsightsCount int
Number of insights that failed
getter/setter pair
generationCreativity int?
Creativity level (0-100), maps to AI temperature
getter/setter pair
generationIncludeCitations bool?
Whether to include data source citations
getter/setter pair
generationSubheadingCount int?
Number of subheadings (2-5)
getter/setter pair
generationTargetWordCount int?
Target word count (null = auto)
getter/setter pair
generationTemperature double?
Actual temperature used for generation (0.0-2.0)
getter/setter pair
generationTimeMs int?
Time taken to generate article in milliseconds
getter/setter pair
generationTone String?
Writing tone: professional, casual, technical, conversational
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
insightsUsed Object?
Array of insights used: {asset_id, asset_name, value, runtime, success}
getter/setter pair
isPublished bool
Whether this post has been published
getter/setter pair
lastEditedAt DateTime?
When this post was last edited
getter/setter pair
lastUpdated DateTime?
Optional.
getter/setter pair
postId String?
Unique identifier.
getter/setter pair
publishedAt DateTime?
When this post was published
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceCostCredits int
Cost in credits for AI generation service
getter/setter pair
successfulInsightsCount int
Number of insights that succeeded
getter/setter pair
teaser String?
Article teaser/subtitle
getter/setter pair
title String
Article title
getter/setter pair
totalCostCredits int
Total cost in credits (data + service)
getter/setter pair
userId String
User who created this post
getter/setter pair
viewCount int
Number of times this post has been viewed
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Posts?
Returns a new Posts instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Posts>
mapFromJson(dynamic json) Map<String, Posts>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Posts>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.