getPostsByIdPublications method
Get all publications for a post. Shows where this post has been published to external platforms. Returns: Array of publication records with platform, URL, status
Parameters:
Implementation
Future<GetPostsById200Response?> getPostsByIdPublications(String companyId, String postId,) async {
final response = await getPostsByIdPublicationsWithHttpInfo(companyId, postId,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'GetPostsById200Response',) as GetPostsById200Response;
}
return null;
}