toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => 'PostsInput[userId=$userId, companyId=$companyId, title=$title, category=$category, teaser=$teaser, contentHtml=$contentHtml, insightsUsed=$insightsUsed, generationCreativity=$generationCreativity, generationTargetWordCount=$generationTargetWordCount, generationTone=$generationTone, generationIncludeCitations=$generationIncludeCitations, generationSubheadingCount=$generationSubheadingCount, generationTemperature=$generationTemperature, dataCostCredits=$dataCostCredits, serviceCostCredits=$serviceCostCredits, totalCostCredits=$totalCostCredits, successfulInsightsCount=$successfulInsightsCount, failedInsightsCount=$failedInsightsCount, generationTimeMs=$generationTimeMs, isPublished=$isPublished, publishedAt=$publishedAt, viewCount=$viewCount, lastEditedAt=$lastEditedAt]';