StorageEngines class

Constructors

StorageEngines({DateTime? dateCreated, DateTime? lastUpdated, int? engineId, required int providerId, required String serviceName, required StorageEnginesEngineTypeEnum engineType, bool? integrationComplete, bool? testFuncComplete})
Returns a new StorageEngines instance.

Properties

dateCreated DateTime?
Optional.
getter/setter pair
engineId int?
Unique identifier.
getter/setter pair
engineType StorageEnginesEngineTypeEnum
Required. One of: EDW, LLM, RDBMS, OBJ, API_MODEL, … (6 total).
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
integrationComplete bool?
Optional.
getter/setter pair
lastUpdated DateTime?
Optional.
getter/setter pair
providerId int
References cloud_providers.provider_id — Supported cloud platforms and database engines available for connections. See GET /cloud_providers for valid values. Required.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
Required.
getter/setter pair
testFuncComplete bool?
Optional.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StorageEngines?
Returns a new StorageEngines instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StorageEngines>
mapFromJson(dynamic json) Map<String, StorageEngines>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StorageEngines>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.