StorageEnginesApi class

Constructors

StorageEnginesApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStorageEnginesById(String providerId, String engineId) Future<GetStorageEnginesById200Response?>
Get single storage engine by ID
getStorageEnginesByIdWithHttpInfo(String providerId, String engineId) Future<Response>
Get single storage engine by ID
listStorageEngines(String providerId, {int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<ListStorageEngines200Response?>
Get a list of all storage engines
listStorageEnginesWithHttpInfo(String providerId, {int? page, int? limit, String? sortBy, String? sortOrder, String? search}) Future<Response>
Get a list of all storage engines
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited