Users class

Constructors

Users({DateTime? dateCreated, DateTime? lastUpdated, String? userId, required String companyId, required int roleId, int? functionId, required UsersStatusEnum status, String? emailAddress, String? timezone, required bool marketingOptOut})
Returns a new Users instance.

Properties

companyId String
References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.
getter/setter pair
dateCreated DateTime?
Optional.
getter/setter pair
emailAddress String?
Optional. Must be unique.
getter/setter pair
functionId int?
User's job function/title
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
lastUpdated DateTime?
Optional.
getter/setter pair
marketingOptOut bool
Whether user has opted out of marketing communications. Default false = opted in per ToS.
getter/setter pair
roleId int
User's role for RBAC - single source of truth
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status UsersStatusEnum
Required. One of: ACTIVE, PENDING, INACTIVE, BANNED.
getter/setter pair
timezone String?
Optional.
getter/setter pair
userId String?
Unique identifier.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Users?
Returns a new Users instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Users>
mapFromJson(dynamic json) Map<String, Users>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Users>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.