UsersUpdate class

Constructors

UsersUpdate({String? companyId, int? roleId, int? functionId, UsersUpdateStatusEnum? status, String? emailAddress, String? timezone, bool? marketingOptOut})
Returns a new UsersUpdate instance.

Properties

companyId String?
References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.
getter/setter pair
emailAddress String?
Optional. Must be unique.
getter/setter pair
functionId int?
User's job function/title
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
marketingOptOut bool?
Whether user has opted out of marketing communications. Default false = opted in per ToS.
getter/setter pair
roleId int?
User's role for RBAC - single source of truth
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status UsersUpdateStatusEnum?
Required. One of: ACTIVE, PENDING, INACTIVE, BANNED.
getter/setter pair
timezone String?
Optional.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) UsersUpdate?
Returns a new UsersUpdate instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<UsersUpdate>
mapFromJson(dynamic json) Map<String, UsersUpdate>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<UsersUpdate>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.