AssetPriceHistoryApi class
Methods
-
createAssetPriceHistory(String companyId, String assetId, AssetPriceHistoryInput assetPriceHistoryInput)
→ Future<CreateAssetPriceHistory200Response?>
-
Create a new price history record for an asset
-
createAssetPriceHistoryPricesCalculateCredits(String companyId, String assetId, AssetPriceHistoryInput assetPriceHistoryInput)
→ Future<CreateAssetPriceHistory200Response?>
-
Calculate the credit equivalent for a given USD price without saving
-
createAssetPriceHistoryPricesCalculateCreditsWithHttpInfo(String companyId, String assetId, AssetPriceHistoryInput assetPriceHistoryInput)
→ Future<Response>
-
Calculate the credit equivalent for a given USD price without saving
-
createAssetPriceHistoryPricesDiscount(String companyId, String assetId, AssetPriceHistoryInput assetPriceHistoryInput)
→ Future<CreateAssetPriceHistory200Response?>
-
POST /companies/{company_id}/assets/{asset_id}/prices/discount
-
createAssetPriceHistoryPricesDiscountWithHttpInfo(String companyId, String assetId, AssetPriceHistoryInput assetPriceHistoryInput)
→ Future<Response>
-
POST /companies/{company_id}/assets/{asset_id}/prices/discount
-
createAssetPriceHistoryWithHttpInfo(String companyId, String assetId, AssetPriceHistoryInput assetPriceHistoryInput)
→ Future<Response>
-
Create a new price history record for an asset
-
deleteAssetPriceHistory(String companyId, String assetId, String aphId)
→ Future<DeleteAssetPriceHistory200Response?>
-
Delete single price history record by ID
-
deleteAssetPriceHistoryWithHttpInfo(String companyId, String assetId, String aphId)
→ Future<Response>
-
Delete single price history record by ID
-
getAssetPriceHistoryById(String companyId, String assetId)
→ Future<GetAssetPriceHistoryById200Response?>
-
Get all price history records for a specific asset
-
getAssetPriceHistoryByIdAssetsPrices(String companyId, String assetId, String aphId)
→ Future<GetAssetPriceHistoryById200Response?>
-
Get single price history record by ID
-
getAssetPriceHistoryByIdAssetsPricesWithHttpInfo(String companyId, String assetId, String aphId)
→ Future<Response>
-
Get single price history record by ID
-
getAssetPriceHistoryByIdPricesActive(String companyId, String assetId)
→ Future<GetAssetPriceHistoryById200Response?>
-
Get the currently active price for an asset
-
getAssetPriceHistoryByIdPricesActiveWithHttpInfo(String companyId, String assetId)
→ Future<Response>
-
Get the currently active price for an asset
-
getAssetPriceHistoryByIdWithHttpInfo(String companyId, String assetId)
→ Future<Response>
-
Get all price history records for a specific asset
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateAssetPriceHistory(String companyId, String assetId, String aphId, AssetPriceHistoryUpdate assetPriceHistoryUpdate)
→ Future<UpdateAssetPriceHistory200Response?>
-
Update an existing price history record by ID
-
updateAssetPriceHistoryWithHttpInfo(String companyId, String assetId, String aphId, AssetPriceHistoryUpdate assetPriceHistoryUpdate)
→ Future<Response>
-
Update an existing price history record by ID