AssetUsecases class
Constructors
- AssetUsecases({DateTime? dateCreated, DateTime? lastUpdated, int? aucId, required String aucName, String? slug, String? aucDescription})
- Returns a new AssetUsecases instance.
Properties
- aucDescription ↔ String?
-
Optional.
getter/setter pair
- aucId ↔ int?
-
Unique identifier.
getter/setter pair
- aucName ↔ String
-
Required. Must be unique.
getter/setter pair
- dateCreated ↔ DateTime?
-
Optional.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastUpdated ↔ DateTime?
-
Optional.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug ↔ String?
-
URL-friendly slug derived from auc_name (e.g. 'competitive-benchmarking')
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AssetUsecases? -
Returns a new AssetUsecases instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AssetUsecases> -
mapFromJson(
dynamic json) → Map< String, AssetUsecases> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AssetUsecases> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.