AssetsApi class
Methods
createAssets (String companyId , AssetsInput assetsInput , {int ? page , int ? limit , String ? sortBy , String ? sortOrder , String ? search })
→ Future <CreateAssetsAnalyze200Response ? >
Create a new asset
createAssetsAnalyze (String companyHandle , String assetSlug , AssetsInput assetsInput )
→ Future <CreateAssetsAnalyze200Response ? >
Process (analyze) an asset with dynamic rate limiting applied via decorator.
createAssetsAnalyzeWithHttpInfo (String companyHandle , String assetSlug , AssetsInput assetsInput )
→ Future <Response >
Process (analyze) an asset with dynamic rate limiting applied via decorator.
createAssetsScanColumn (String companyId , String assetId , AssetsInput assetsInput )
→ Future <CreateAssetsAnalyze200Response ? >
Scan a column in the asset's table to retrieve distinct values Request Body: column (str): Column name to scan limit (int, optional): Maximum distinct values to return (default 1000, max 5000) Returns: Flask Response with scan results
createAssetsScanColumnWithHttpInfo (String companyId , String assetId , AssetsInput assetsInput )
→ Future <Response >
Scan a column in the asset's table to retrieve distinct values Request Body: column (str): Column name to scan limit (int, optional): Maximum distinct values to return (default 1000, max 5000) Returns: Flask Response with scan results
createAssetsTest (String companyId , String assetId , AssetsInput assetsInput )
→ Future <CreateAssetsAnalyze200Response ? >
POST /companies/{company_id}/assets/{asset_id}/test
createAssetsTestWithHttpInfo (String companyId , String assetId , AssetsInput assetsInput )
→ Future <Response >
POST /companies/{company_id}/assets/{asset_id}/test
createAssetsWithHttpInfo (String companyId , AssetsInput assetsInput , {int ? page , int ? limit , String ? sortBy , String ? sortOrder , String ? search })
→ Future <Response >
Create a new asset
deleteAssets (String companyId , String assetId )
→ Future <DeleteAssets200Response ? >
Delete single asset by ID
deleteAssetsWithHttpInfo (String companyId , String assetId )
→ Future <Response >
Delete single asset by ID
getAssetsById (String companyId , String assetId )
→ Future <GetAssetsByIdAnalyze200Response ? >
Get single asset by ID
getAssetsById2 (String companyId , String assetId )
→ Future <GetAssetsByIdAnalyze200Response ? >
Get statistics for a specific asset (public endpoint)
getAssetsById2WithHttpInfo (String companyId , String assetId )
→ Future <Response >
Get statistics for a specific asset (public endpoint)
getAssetsByIdAnalyze (String companyHandle , String assetSlug )
→ Future <GetAssetsByIdAnalyze200Response ? >
Process (analyze) an asset with dynamic rate limiting applied via decorator.
getAssetsByIdAnalyzeWithHttpInfo (String companyHandle , String assetSlug )
→ Future <Response >
Process (analyze) an asset with dynamic rate limiting applied via decorator.
getAssetsByIdInfoschema (String companyId , String assetId )
→ Future <GetAssetsByIdAnalyze200Response ? >
Get the information schema for a specific asset's table
getAssetsByIdInfoschemaSave (String companyId , String assetId )
→ Future <GetAssetsByIdAnalyze200Response ? >
Retrieve and save an asset's information schema
getAssetsByIdInfoschemaSaveWithHttpInfo (String companyId , String assetId )
→ Future <Response >
Retrieve and save an asset's information schema
getAssetsByIdInfoschemaWithHttpInfo (String companyId , String assetId )
→ Future <Response >
Get the information schema for a specific asset's table
getAssetsByIdPredictedPrice (String companyId , String assetId )
→ Future <GetAssetsByIdAnalyze200Response ? >
Get AI-predicted pricing for a specific asset
getAssetsByIdPredictedPriceWithHttpInfo (String companyId , String assetId )
→ Future <Response >
Get AI-predicted pricing for a specific asset
getAssetsByIdStatistics (String companyId )
→ Future <GetAssetsByIdAnalyze200Response ? >
Get statistics for all assets the user has access to
getAssetsByIdStatisticsWithHttpInfo (String companyId )
→ Future <Response >
Get statistics for all assets the user has access to
getAssetsByIdTest (String companyId , String assetId )
→ Future <GetAssetsByIdAnalyze200Response ? >
GET /companies/{company_id}/assets/{asset_id}/test
getAssetsByIdTestWithHttpInfo (String companyId , String assetId )
→ Future <Response >
GET /companies/{company_id}/assets/{asset_id}/test
getAssetsByIdWithHttpInfo (String companyId , String assetId )
→ Future <Response >
Get single asset by ID
listAssets (String companyId , {int ? page , int ? limit , String ? sortBy , String ? sortOrder , String ? search })
→ Future <ListAssets200Response ? >
Get all assets for a specific company
listAssetsSearch (String companyId , {int ? page , int ? limit , String ? sortBy , String ? sortOrder , String ? search })
→ Future <ListAssets200Response ? >
Search and filter assets with advanced options Query Parameters: q: Search query string category: Filter by category sport: Filter by sport tag sort_by: Sort field (name|recent|popular|trending) limit: Number of results (default 20, max 100) offset: Offset for pagination include_recommended: Include recommendations (true/false) include_schema: Include asset_schema in response (true/false, default false)
listAssetsSearchWithHttpInfo (String companyId , {int ? page , int ? limit , String ? sortBy , String ? sortOrder , String ? search })
→ Future <Response >
Search and filter assets with advanced options Query Parameters: q: Search query string category: Filter by category sport: Filter by sport tag sort_by: Sort field (name|recent|popular|trending) limit: Number of results (default 20, max 100) offset: Offset for pagination include_recommended: Include recommendations (true/false) include_schema: Include asset_schema in response (true/false, default false)
listAssetsWithHttpInfo (String companyId , {int ? page , int ? limit , String ? sortBy , String ? sortOrder , String ? search })
→ Future <Response >
Get all assets for a specific company
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
updateAssets (String companyId , String assetId , AssetsUpdate assetsUpdate )
→ Future <UpdateAssets200Response ? >
Update an existing asset by ID
updateAssetsWithHttpInfo (String companyId , String assetId , AssetsUpdate assetsUpdate )
→ Future <Response >
Update an existing asset by ID