createAssetsAnalyze method
Future<CreateAssetsAnalyze200Response?>
createAssetsAnalyze(
- String companyHandle,
- String assetSlug,
- AssetsInput assetsInput
Process (analyze) an asset with dynamic rate limiting applied via decorator.
Parameters:
-
String companyHandle (required): Human-readable handle for the Company
-
String assetSlug (required): URL-friendly slug for the Asset
-
AssetsInput assetsInput (required):
Implementation
Future<CreateAssetsAnalyze200Response?> createAssetsAnalyze(String companyHandle, String assetSlug, AssetsInput assetsInput,) async {
final response = await createAssetsAnalyzeWithHttpInfo(companyHandle, assetSlug, assetsInput,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'CreateAssetsAnalyze200Response',) as CreateAssetsAnalyze200Response;
}
return null;
}