ConnectionsInput class
Constructors
- ConnectionsInput({String? userId, required int engineId, required String companyId, ConnectionsInputCredentialTypeEnum? credentialType, String? name, String? description, String? providerDomain, bool? verifiedUsageAbility})
- Returns a new ConnectionsInput instance.
Properties
- companyId ↔ String
-
References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.
getter/setter pair
- credentialType ↔ ConnectionsInputCredentialTypeEnum?
-
Optional. One of: SERVICE_ACCOUNT, USERNAME_PASSWORD, API_KEY, SERVICE_IDENTITY, ACCESS_KEY, … (10 total).
getter/setter pair
- description ↔ String?
-
Optional.
getter/setter pair
- engineId ↔ int
-
References storage_engines.engine_id — Fact table of all the different storage engines we support. See GET /storage_engines for valid values. Required.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String?
-
Optional.
getter/setter pair
- providerDomain ↔ String?
-
Domain of the external API provider (e.g., 'api.weather.com')
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId ↔ String?
-
References users.user_id — An individual user account within a company. See GET /users for valid values. Optional.
getter/setter pair
- verifiedUsageAbility ↔ bool?
-
Optional.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ConnectionsInput? -
Returns a new ConnectionsInput instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< ConnectionsInput> -
mapFromJson(
dynamic json) → Map< String, ConnectionsInput> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< ConnectionsInput> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.