EndpointsApi class
Methods
createEndpoints (String companyId , EndpointsInput endpointsInput , {int ? page , int ? limit , String ? sortBy , String ? sortOrder , String ? search })
→ Future <CreateEndpoints200Response ? >
Create a new endpoint
createEndpointsKeys (String companyId , String endpointId , EndpointsInput endpointsInput )
→ Future <CreateEndpoints200Response ? >
POST /companies/{company_id}/endpoints/{endpoint_id}/keys
createEndpointsKeysWithHttpInfo (String companyId , String endpointId , EndpointsInput endpointsInput )
→ Future <Response >
POST /companies/{company_id}/endpoints/{endpoint_id}/keys
createEndpointsScanColumn (String companyId , String endpointId , EndpointsInput endpointsInput )
→ Future <CreateEndpoints200Response ? >
POST /companies/{company_id}/endpoints/{endpoint_id}/scan_column
createEndpointsScanColumnWithHttpInfo (String companyId , String endpointId , EndpointsInput endpointsInput )
→ Future <Response >
POST /companies/{company_id}/endpoints/{endpoint_id}/scan_column
createEndpointsWithHttpInfo (String companyId , EndpointsInput endpointsInput , {int ? page , int ? limit , String ? sortBy , String ? sortOrder , String ? search })
→ Future <Response >
Create a new endpoint
deleteEndpoints (String companyId , String endpointId )
→ Future <DeleteEndpoints200Response ? >
Delete single endpoint by ID
deleteEndpointsKeys (String companyId , String endpointId , String apiKeyId )
→ Future <DeleteEndpoints200Response ? >
DELETE /companies/{company_id}/endpoints/{endpoint_id}/keys/{api_key_id}
deleteEndpointsKeysWithHttpInfo (String companyId , String endpointId , String apiKeyId )
→ Future <Response >
DELETE /companies/{company_id}/endpoints/{endpoint_id}/keys/{api_key_id}
deleteEndpointsWithHttpInfo (String companyId , String endpointId )
→ Future <Response >
Delete single endpoint by ID
getEndpointsById (String companyId , String endpointId )
→ Future <GetEndpointsByIdConnectionsDescribe200Response ? >
Get single endpoint by ID
getEndpointsByIdAvailableEndpoints (String companyId , String endpointId )
→ Future <GetEndpointsByIdConnectionsDescribe200Response ? >
GET /companies/{company_id}/endpoints/{endpoint_id}/available-endpoints
getEndpointsByIdAvailableEndpointsWithHttpInfo (String companyId , String endpointId )
→ Future <Response >
GET /companies/{company_id}/endpoints/{endpoint_id}/available-endpoints
getEndpointsByIdConnectionsDescribe (String companyId , String connectionId )
→ Future <GetEndpointsByIdConnectionsDescribe200Response ? >
Get schema information for a connection Query parameters: include_fields: Whether to include field information (default: true) schemas: Optional comma-separated schemas to include tables: Optional comma-separated tables to include
getEndpointsByIdConnectionsDescribeWithHttpInfo (String companyId , String connectionId )
→ Future <Response >
Get schema information for a connection Query parameters: include_fields: Whether to include field information (default: true) schemas: Optional comma-separated schemas to include tables: Optional comma-separated tables to include
getEndpointsByIdExecute (String companyId , String endpointId )
→ Future <GetEndpointsByIdConnectionsDescribe200Response ? >
Execute an endpoint with pagination support. Customer-facing route that returns paginated data. Query params: ?start=0&limit=100
getEndpointsByIdExecuteWithHttpInfo (String companyId , String endpointId )
→ Future <Response >
Execute an endpoint with pagination support. Customer-facing route that returns paginated data. Query params: ?start=0&limit=100
getEndpointsByIdKeys (String companyId , String endpointId )
→ Future <GetEndpointsByIdConnectionsDescribe200Response ? >
GET /companies/{company_id}/endpoints/{endpoint_id}/keys
getEndpointsByIdKeysWithHttpInfo (String companyId , String endpointId )
→ Future <Response >
GET /companies/{company_id}/endpoints/{endpoint_id}/keys
getEndpointsByIdRecommendations (String companyId , String endpointId )
→ Future <GetEndpointsByIdConnectionsDescribe200Response ? >
GET /companies/{company_id}/endpoints/{endpoint_id}/recommendations
getEndpointsByIdRecommendationsWithHttpInfo (String companyId , String endpointId )
→ Future <Response >
GET /companies/{company_id}/endpoints/{endpoint_id}/recommendations
getEndpointsByIdStats (String companyId , String endpointId )
→ Future <GetEndpointsByIdConnectionsDescribe200Response ? >
Get usage statistics for an endpoint Query parameters: days: Number of days to analyze (default: 30)
getEndpointsByIdStatsWithHttpInfo (String companyId , String endpointId )
→ Future <Response >
Get usage statistics for an endpoint Query parameters: days: Number of days to analyze (default: 30)
getEndpointsByIdTest (String companyId , String endpointId )
→ Future <GetEndpointsByIdConnectionsDescribe200Response ? >
Test an endpoint with sample data Request body (optional): limit: Number of sample rows to return (default: 10)
getEndpointsByIdTestWithHttpInfo (String companyId , String endpointId )
→ Future <Response >
Test an endpoint with sample data Request body (optional): limit: Number of sample rows to return (default: 10)
getEndpointsByIdUrl (String companyId , String endpointId )
→ Future <GetEndpointsByIdConnectionsDescribe200Response ? >
GET /companies/{company_id}/endpoints/{endpoint_id}/url
getEndpointsByIdUrlWithHttpInfo (String companyId , String endpointId )
→ Future <Response >
GET /companies/{company_id}/endpoints/{endpoint_id}/url
getEndpointsByIdWithHttpInfo (String companyId , String endpointId )
→ Future <Response >
Get single endpoint by ID
listEndpoints (String companyId , {int ? page , int ? limit , String ? sortBy , String ? sortOrder , String ? search })
→ Future <ListEndpoints200Response ? >
Get all endpoints for a specific company with pagination, filtering, and sorting
listEndpointsWithHttpInfo (String companyId , {int ? page , int ? limit , String ? sortBy , String ? sortOrder , String ? search })
→ Future <Response >
Get all endpoints for a specific company with pagination, filtering, and sorting
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
updateEndpoints (String companyId , String endpointId , EndpointsUpdate endpointsUpdate )
→ Future <UpdateEndpoints200Response ? >
Update an existing endpoint by ID
updateEndpointsWithHttpInfo (String companyId , String endpointId , EndpointsUpdate endpointsUpdate )
→ Future <Response >
Update an existing endpoint by ID