FavoritesApi class
Methods
-
createFavorites(String companyId, String userId, FavoritesInput favoritesInput)
→ Future<CreateFavorites200Response?>
-
POST /companies/{company_id}/users/{user_id}/favorites
-
createFavoritesWithHttpInfo(String companyId, String userId, FavoritesInput favoritesInput)
→ Future<Response>
-
POST /companies/{company_id}/users/{user_id}/favorites
-
deleteFavorites(String companyId, String userId, String favoriteId)
→ Future<DeleteFavorites200Response?>
-
Delete single favorite by ID (unfavorite an asset)
-
deleteFavoritesWithHttpInfo(String companyId, String userId, String favoriteId)
→ Future<Response>
-
Delete single favorite by ID (unfavorite an asset)
-
getFavoritesById(String companyId, String userId)
→ Future<GetFavoritesById200Response?>
-
Get a list of all favorites for a specific user
-
getFavoritesByIdUsers(String companyId, String userId, String favoriteId)
→ Future<GetFavoritesById200Response?>
-
Get single favorite by ID
-
getFavoritesByIdUsersCategory(String companyId, String userId, String category)
→ Future<GetFavoritesById200Response?>
-
Get all favorites for the specified user in a specific category
-
getFavoritesByIdUsersCategoryWithHttpInfo(String companyId, String userId, String category)
→ Future<Response>
-
Get all favorites for the specified user in a specific category
-
getFavoritesByIdUsersCheck(String companyId, String userId, String assetId)
→ Future<GetFavoritesById200Response?>
-
Check if the specified user has favorited a specific asset
-
getFavoritesByIdUsersCheckWithHttpInfo(String companyId, String userId, String assetId)
→ Future<Response>
-
Check if the specified user has favorited a specific asset
-
getFavoritesByIdUsersUncategorized(String companyId, String userId)
→ Future<GetFavoritesById200Response?>
-
Get all favorites for the specified user that don't have a category
-
getFavoritesByIdUsersUncategorizedWithHttpInfo(String companyId, String userId)
→ Future<Response>
-
Get all favorites for the specified user that don't have a category
-
getFavoritesByIdUsersWithHttpInfo(String companyId, String userId, String favoriteId)
→ Future<Response>
-
Get single favorite by ID
-
getFavoritesByIdWithHttpInfo(String companyId, String userId)
→ Future<Response>
-
Get a list of all favorites for a specific user
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateFavorites(String companyId, String userId, String favoriteId, FavoritesUpdate favoritesUpdate)
→ Future<UpdateFavorites200Response?>
-
Update an existing favorite by ID
-
updateFavoritesWithHttpInfo(String companyId, String userId, String favoriteId, FavoritesUpdate favoritesUpdate)
→ Future<Response>
-
Update an existing favorite by ID