FavoritesInput class
Constructors
- FavoritesInput({required String assetId, String? userId, required String companyId, String? notes, String? category, int? priority})
- Returns a new FavoritesInput instance.
Properties
- assetId ↔ String
-
References assets.asset_id — A published analytics asset — a calculation or visualization built on a data connection. See GET /assets for valid values. Required.
getter/setter pair
- category ↔ String?
-
Optional category for organizing favorites (e.g., 'Work', 'Research')
getter/setter pair
- companyId ↔ String
-
References companies.company_id — A Spartera seller or buyer company account. See GET /companies for valid values. Required.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- notes ↔ String?
-
Optional user notes about this favorite
getter/setter pair
- priority ↔ int?
-
User-defined priority for sorting (higher = more important)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId ↔ String?
-
References users.user_id — An individual user account within a company. See GET /users for valid values. Optional.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → FavoritesInput? -
Returns a new FavoritesInput instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< FavoritesInput> -
mapFromJson(
dynamic json) → Map< String, FavoritesInput> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< FavoritesInput> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.