PostgenIntegrationsApi class
Methods
-
createPostgenIntegrations(String companyId, PostgenIntegrationsInput postgenIntegrationsInput, {int? page, int? limit, String? sortBy, String? sortOrder, String? search})
→ Future<CreatePostgenIntegrations200Response?>
-
POST /companies/{company_id}/postgen_integrations
-
createPostgenIntegrationsTest(String companyId, PostgenIntegrationsInput postgenIntegrationsInput)
→ Future<CreatePostgenIntegrations200Response?>
-
POST /companies/{company_id}/postgen_integrations/test
-
createPostgenIntegrationsTestWithHttpInfo(String companyId, PostgenIntegrationsInput postgenIntegrationsInput)
→ Future<Response>
-
POST /companies/{company_id}/postgen_integrations/test
-
createPostgenIntegrationsWithHttpInfo(String companyId, PostgenIntegrationsInput postgenIntegrationsInput, {int? page, int? limit, String? sortBy, String? sortOrder, String? search})
→ Future<Response>
-
POST /companies/{company_id}/postgen_integrations
-
deletePostgenIntegrations(String companyId, String integrationId)
→ Future<DeletePostgenIntegrations200Response?>
-
Delete single integration by ID. Also deletes credentials from GCP Secret Manager.
-
deletePostgenIntegrationsWithHttpInfo(String companyId, String integrationId)
→ Future<Response>
-
Delete single integration by ID. Also deletes credentials from GCP Secret Manager.
-
getPostgenIntegrationsById(String companyId, String integrationId)
→ Future<GetPostgenIntegrationsById200Response?>
-
Get single integration by ID.
-
getPostgenIntegrationsByIdWithHttpInfo(String companyId, String integrationId)
→ Future<Response>
-
Get single integration by ID.
-
listPostgenIntegrations(String companyId, {int? page, int? limit, String? sortBy, String? sortOrder, String? search})
→ Future<ListPostgenIntegrations200Response?>
-
Get a list of all postgen integrations for the company. All company users can view integrations.
-
listPostgenIntegrationsWithHttpInfo(String companyId, {int? page, int? limit, String? sortBy, String? sortOrder, String? search})
→ Future<Response>
-
Get a list of all postgen integrations for the company. All company users can view integrations.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updatePostgenIntegrations(String companyId, String integrationId, PostgenIntegrationsUpdate postgenIntegrationsUpdate)
→ Future<UpdatePostgenIntegrations200Response?>
-
Update an existing integration by ID. Can update credentials, is_active status, etc.
-
updatePostgenIntegrationsWithHttpInfo(String companyId, String integrationId, PostgenIntegrationsUpdate postgenIntegrationsUpdate)
→ Future<Response>
-
Update an existing integration by ID. Can update credentials, is_active status, etc.